@@ -11,6 +11,13 @@ ERROR_INFO = {
 }
 
 
+try:
+    TEXT = unicode
+    UNICODE = unicode
+except NameError:
+    TEXT = str
+    UNICODE = str
+
 def clean_language_name(language):
     if language is None:
         return LANGUAGE
@@ -53,20 +60,25 @@ class BizErrorBase(RuntimeError):
             code = code or info["code"]
             message = message or info["message"]
         # message format
-        if not isinstance(message, str):
-            message = str(message)
+        if not isinstance(message, TEXT):
+            message = TEXT(str(message), encoding="utf-8")
         if kwargs:
             message = message.format(**kwargs)
-        super().__init__(code, message)
+        super(BizErrorBase, self).__init__(code, message)
 
     def __repr__(self):
         return str(self)
 
     def __str__(self):
-        return json.dumps({
+        result = json.dumps({
             "code": self.args[0],
             "message": self.args[1]
         }, ensure_ascii=False)
+        if TEXT == str:
+            return result
+        else:
+            result = result.encode("utf-8")
+            return result
 
     @property
     def code(self):
